==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/realm/entity/MapIdentityProviderEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapIdentityProviderEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapIdentityProviderEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapIdentityProviderEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapIdentityProviderEntity> entityFieldDelegate;
    public MapIdentityProviderEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapIdentityProviderEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapIdentityProviderEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAlias() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ALIAS);
    }
    @SuppressWarnings("unchecked") @Override public void setAlias(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ALIAS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getDisplayName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.DISPLAY_NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setDisplayName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.DISPLAY_NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getProviderId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.PROVIDER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setProviderId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.PROVIDER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getFirstBrokerLoginFlowId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.FIRST_BROKER_LOGIN_FLOW_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setFirstBrokerLoginFlowId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.FIRST_BROKER_LOGIN_FLOW_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getPostBrokerLoginFlowId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.POST_BROKER_LOGIN_FLOW_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setPostBrokerLoginFlowId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.POST_BROKER_LOGIN_FLOW_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isEnabled() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ENABLED);
    }
    @SuppressWarnings("unchecked") @Override public void setEnabled(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ENABLED, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isTrustEmail() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.TRUST_EMAIL);
    }
    @SuppressWarnings("unchecked") @Override public void setTrustEmail(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.TRUST_EMAIL, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isStoreToken() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.STORE_TOKEN);
    }
    @SuppressWarnings("unchecked") @Override public void setStoreToken(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.STORE_TOKEN, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isLinkOnly() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.LINK_ONLY);
    }
    @SuppressWarnings("unchecked") @Override public void setLinkOnly(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.LINK_ONLY, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isAddReadTokenRoleOnCreate() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ADD_READ_TOKEN_ROLE_ON_CREATE);
    }
    @SuppressWarnings("unchecked") @Override public void setAddReadTokenRoleOnCreate(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ADD_READ_TOKEN_ROLE_ON_CREATE, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isAuthenticateByDefault() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.AUTHENTICATE_BY_DEFAULT);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthenticateByDefault(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.AUTHENTICATE_BY_DEFAULT, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getConfig() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.CONFIG);
    }
    @SuppressWarnings("unchecked") @Override public void setConfig(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.CONFIG, p0);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapIdentityProviderEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapIdentityProviderEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapIdentityProviderEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapIdentityProviderEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapIdentityProviderEntity> entityFieldDelegate;
    public MapIdentityProviderEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapIdentityProviderEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapIdentityProviderEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAlias() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ALIAS);
    }
    @SuppressWarnings("unchecked") @Override public void setAlias(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ALIAS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getDisplayName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.DISPLAY_NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setDisplayName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.DISPLAY_NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getProviderId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.PROVIDER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setProviderId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.PROVIDER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getFirstBrokerLoginFlowId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.FIRST_BROKER_LOGIN_FLOW_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setFirstBrokerLoginFlowId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.FIRST_BROKER_LOGIN_FLOW_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getPostBrokerLoginFlowId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.POST_BROKER_LOGIN_FLOW_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setPostBrokerLoginFlowId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.POST_BROKER_LOGIN_FLOW_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isEnabled() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ENABLED);
    }
    @SuppressWarnings("unchecked") @Override public void setEnabled(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ENABLED, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isTrustEmail() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.TRUST_EMAIL);
    }
    @SuppressWarnings("unchecked") @Override public void setTrustEmail(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.TRUST_EMAIL, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isStoreToken() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.STORE_TOKEN);
    }
    @SuppressWarnings("unchecked") @Override public void setStoreToken(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.STORE_TOKEN, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isLinkOnly() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.LINK_ONLY);
    }
    @SuppressWarnings("unchecked") @Override public void setLinkOnly(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.LINK_ONLY, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isAddReadTokenRoleOnCreate() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ADD_READ_TOKEN_ROLE_ON_CREATE);
    }
    @SuppressWarnings("unchecked") @Override public void setAddReadTokenRoleOnCreate(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ADD_READ_TOKEN_ROLE_ON_CREATE, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isAuthenticateByDefault() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.AUTHENTICATE_BY_DEFAULT);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthenticateByDefault(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.AUTHENTICATE_BY_DEFAULT, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getConfig() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.CONFIG);
    }
    @SuppressWarnings("unchecked") @Override public void setConfig(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.CONFIG, p0);
    }
}
